package com.example.bpa.app;


import com.example.bpa.config.ConfigName;
import com.example.bpa.config.DataBus;
import com.example.bpa.db.QueryDB;
import com.example.bpa.db.mode.BPA_SYSTEMSET;
import com.example.bpa.db.mode.BPA_USER;
import com.example.bpa.helper.ConfigUtil;
import com.example.bpa.helper.T;
import com.example.bpa.helper.UpdateManager;

import java.util.ArrayList;

/**
 * 主函数进程
 * 主要进行配置文件-系统类
 */
public class Main {
    //region 私有
    private static Main mInstance; //实例变量设置私有，防止直接通过类名访问

    public static synchronized Main getInstance() { //静态同步方法作为唯一的实例对象获取方式
        if (mInstance == null) {
            mInstance = new Main();
        }
        return mInstance;
    }

    private Main() { //默认构造函数私有，防止类外直接new创建对象
        Init();
    }
    //endregion

    //region 外部调用事件

    /**
     * 初始化
     */
    public void Init() {
        //1.加载系统设置
        LoadSystem();
        //2.加载配置
        LoadingDPPZ();
        LoadingPZ();
        //3.初始化业务
        //4.初始化日志上报adad
    }

    /**
     * 加载系统配置
     */
    public void LoadSystem()
    {
        ArrayList<BPA_SYSTEMSET> bpa_systemsets= QueryDB.GetSystemsetALL();
        for (int i = 0; i <17;i++){
            int ty=i+1;
            BPA_SYSTEMSET set=new BPA_SYSTEMSET();
            set.type=ty;
            switch (ty)
            {
                case 1:
                    set.value=String.valueOf(ConfigName.getInstance().OrderPushTime);
                    break;
                case 2:
                    set.value=String.valueOf(ConfigName.getInstance().SilosValuePushTime);
                    break;
                case 3:
                    set.value=String.valueOf(ConfigName.getInstance().OtherValuePushTime);
                    break;
                case 4:
                    set.value=String.valueOf(ConfigName.getInstance().PipeDrainCycleTime);
                    break;
                case 5:
                    set.value=String.valueOf(ConfigName.getInstance().OrderTimeout);
                    break;
                case 6:
                    set.value=String.valueOf(ConfigName.getInstance().SiloFeedThreshold);
                    break;
                case 7:
                    set.value=String.valueOf(ConfigName.getInstance().SiloAlarmThreshold);
                    break;
                case 8:
                    set.value=String.valueOf(ConfigName.getInstance().AICleanTime);
                    break;
                case 9:
                    set.value=ConfigName.getInstance().AutKey;
                    break;
                case 10:
                    set.value=ConfigName.getInstance().Address;
                    break;
                case 11:
                    set.value=String.valueOf(ConfigName.getInstance().Post);
                    break;
                case 12:
                    set.value=ConfigName.getInstance().mqtt_userName;
                    break;
                case 13:
                    set.value=ConfigName.getInstance().mqtt_passWord;
                    break;
                case 14:
                    set.value=ConfigName.getInstance().mqtt_ip;
                    break;
                case 15:
                    set.value=String.valueOf(ConfigName.getInstance().mqtt_post);
                    break;
                case 16:
                    set.value=ConfigName.getInstance().mqtt_topic;
                    break;
            }
            set.deviceID = ConfigName.getInstance().DeviceId;
            set.userID = ConfigName.getInstance().user.userID;

            BPA_SYSTEMSET find=null;
            for (BPA_SYSTEMSET item:bpa_systemsets)
            {
                if(item.type==ty)
                {
                    find=item;
                    break;
                }
            }
            if(find==null)
            {
                QueryDB.AddSystemset(set);
            }
        }

        for (BPA_SYSTEMSET item:bpa_systemsets)
        {
            switch (item.type)
            {
                case 1:
                    ConfigName.getInstance().OrderPushTime=Integer.parseInt(item.value);
                    break;
                case 2:
                    ConfigName.getInstance().SilosValuePushTime=Integer.parseInt(item.value);
                    break;
                case 3:
                    ConfigName.getInstance().OtherValuePushTime=Integer.parseInt(item.value);
                    break;
                case 4:
                    ConfigName.getInstance().PipeDrainCycleTime=Integer.parseInt(item.value);
                    break;
                case 5:
                    ConfigName.getInstance().OrderTimeout=Integer.parseInt(item.value);
                    break;
                case 6:
                    ConfigName.getInstance().SiloFeedThreshold=Integer.parseInt(item.value);
                    break;
                case 7:
                    ConfigName.getInstance().SiloAlarmThreshold=Integer.parseInt(item.value);
                    break;
                case 8:
                    ConfigName.getInstance().AICleanTime=Integer.parseInt(item.value);
                    break;
                case 9:
                    ConfigName.getInstance().AutKey=item.value;
                    break;
                case 10:
                    ConfigName.getInstance().Address=item.value;
                    break;
                case 11:
                    ConfigName.getInstance().Post=Integer.parseInt(item.value);
                    break;
                case 12:
                    ConfigName.getInstance().mqtt_userName=item.value;
                    break;
                case 13:
                    ConfigName.getInstance().mqtt_passWord=item.value;
                    break;
                case 14:
                    ConfigName.getInstance().mqtt_ip=item.value;
                    break;
                case 15:
                    ConfigName.getInstance().mqtt_post=Integer.parseInt(item.value);
                    break;
                case 16:
                    ConfigName.getInstance().mqtt_topic=item.value;
                    break;
            }

        }
    }
    /**
     * 加载店铺配置
     */
    public void LoadingDPPZ() {
        //ConfigName.getInstance().AutKey
        ConfigName.getInstance().Shop_Name="黑菠萝奶茶机";
        ConfigName.getInstance().DeviceId="20020415-test";
    }
    /**
     * 加载配置
     */
    public void LoadingPZ() {
        //1.店铺配置
//        ConfigName.getInstance().Shop_Name = ConfigUtil.read(ConfigName.getInstance().dishesCon, "Shop_Name", ConfigName.getInstance().Shop_Name);
//        ConfigName.getInstance().AutKey = ConfigUtil.read(ConfigName.getInstance().dishesCon, "AutKey", ConfigName.getInstance().AutKey);
        //2.用户名称
        ConfigName.getInstance().user.account = ConfigUtil.read(ConfigName.getInstance().dishesCon, "username", ConfigName.getInstance().user.account);
        ConfigName.getInstance().user.pass = ConfigUtil.read(ConfigName.getInstance().dishesCon, "password", ConfigName.getInstance().user.pass);
    }

    /**
     * 保存配置
     */
    public void SavePZ()
    {
        //1.店铺配置
//        ConfigUtil.write(ConfigName.getInstance().dishesCon,"Shop_Name", ConfigName.getInstance().Shop_Name);
//        ConfigUtil.write(ConfigName.getInstance().dishesCon,"AutKey", ConfigName.getInstance().AutKey);
        //2.用户信息
        ConfigUtil.write(ConfigName.getInstance().dishesCon,"username", ConfigName.getInstance().user.account);
        ConfigUtil.write(ConfigName.getInstance().dishesCon,"password", ConfigName.getInstance().user.pass);
    }
    //endregion
}
