package com.example.bpa.service;

import com.example.bpa.Model.IMessage;
import com.example.bpa.Model.IRun;
import com.example.bpa.Model.IThread;
import com.example.bpa.config.ConfigName;
import com.example.bpa.db.QueryDB;
import com.example.bpa.db.mode.BPA_SUBORDER;
import com.example.bpa.helper.Json;
import com.example.bpa.helper.MQTT;
import com.example.bpa.helper.MessageLog;
import com.example.bpa.helper.ThreadManager;
import com.example.bpa.view.mode.ResReceiveOrder;

import java.util.concurrent.ConcurrentLinkedQueue;

/**
 * 订单服务
 * 收发订单、订单预警、接收云端订单信息
 */
public class OrderServer {

    //region 私有单例
    private static volatile OrderServer _instance;

    public static OrderServer Get() {
        if (_instance == null)
            _instance = new OrderServer();
        return _instance;
    }

    private OrderServer() {
    }
    //endregion

    //region 变量
    /**
     * 订单接收队列
     */
    ConcurrentLinkedQueue<ResReceiveOrder> Commoditys = new ConcurrentLinkedQueue<ResReceiveOrder>();
    //endreigon

    //region 公共函数

    /**
     * 初始化
     */
    public void Init()
    {
//        ThreadManager.Get().StartLong("订单服务", true, new IThread() {
//            @Override
//            public void Run() throws InterruptedException {
//                MessageLog.ShowInfo("我是订单服务！");
//                Thread.sleep(2000);
//            }
//            @Override
//            public void RunComplete() throws InterruptedException {
//            }
//        });


    }

    /**
     * MQTT初始化
     */
    public void MqttInit()
    {
        //消息回调
        MQTT.get().callback=new IMessage() {
            @Override
            public void MessageRecive(String topic, String Message) {
                MessageLog.ShowInfo("收到主题:"+topic+",数据:"+Message);
                try {
                    if(!Message.isEmpty())
                    {
                        ResReceiveOrder model=new Json<ResReceiveOrder>().jsonToobject(ResReceiveOrder.class,((String)Message));
                        Commoditys.offer(model);
                    }
                } catch (Exception e) {
                }
            }
        };
        //连接成功标志
        MQTT.get().ConnectOk=new IRun() {
            @Override
            public void Run() {
                String[] Str={ConfigName.getInstance().mqtt_topic};
                MQTT.get().Subscrib(Str);
            }
        };
        //初始化MQTT连接
        MQTT.get().Connect(ConfigName.getInstance().mqtt_userName,
                ConfigName.getInstance().mqtt_passWord,
                ConfigName.getInstance().mqtt_ip,
                ConfigName.getInstance().mqtt_post);
        //云端数据处理线程
        ThreadManager.Get().StartLong("云订单接收处理", true, new IThread() {
            @Override
            public void Run() throws InterruptedException {
                if(MQTT.get().IsConnect)
                {
                    while (Commoditys.size() > 0) {
                        //1.取出订单
                        ResReceiveOrder order = Commoditys.poll();
                        if(order.order!=null && order.subOrder!=null)
                        {
                            QueryDB.AddOrder(order.order);
                            for(BPA_SUBORDER suborder: order.subOrder)
                            {
                                QueryDB.AddSubOrder(suborder);
                                //向订单执行队列增加子订单
                                BusinessServer.Get().AddCommodity(suborder);
                            }
                        }
                    }
                }
                Thread.sleep(2000);
            }
            @Override
            public void RunComplete() throws InterruptedException {
            }
        });
    }
    //endregion
}
